@@ -35,7 +35,6 @@
 #include "plfiles.h"
 #include "fifiles.h"
 #include "iefiles.h"
-#include "skfiles.h"
 #include "infoaccess.h"
 
 struct InfoAccessPrivate {
@@ -70,8 +69,6 @@ InfoAccess::InfoAccess( QObject *parent , QString region)
 	else if ( _region == "PL" ) { dataDownloader = new PLFiles(this); }
 	else if ( _region == "FI" ) { dataDownloader = new FIFiles(this); }
 	else if ( _region == "IE" ) { dataDownloader = new IEFiles(this); }
-	else if ( _region == "SK" ) { dataDownloader = new SKFiles(this); }
-	else if ( _region == "CZ" ) { dataDownloader = new SKFiles(this); }
 	else { dataDownloader = new UKFiles(this); }  // default is UK
 
 	d = new InfoAccessPrivate;
