@@ -233,6 +233,13 @@ MainWindow::MainWindow()
 	connect(_recordButton, SIGNAL(clicked()), this, SLOT(showRecordMessage()));
 	connect(_remindButton, SIGNAL(clicked()), this, SLOT(showRemindMessage()));
 	connect(this, SIGNAL(downloadIndex(int)), _progress, SLOT(setValue(int)));
+
+	//////////////////////////////////////////////////////////////////	
+	//#### show the default screen from the settings, if nothing is
+	//#### set then show daily mode
+	//////////////////////////////////////////////////////////////////	
+	showDefaultScreen();
+	//////////////////////////////////////////////////////////////////	
 }
 
 // LOADS THE APP SETTINGS TO MEMORY
@@ -370,6 +377,24 @@ void MainWindow::createMenus()
 	menu->addAction(donateAct);
 }
 
+//SHOW the default screen as set by the user, if nothing is set show daily mode
+void MainWindow::showDefaultScreen()
+{
+	if ( _settingsWindow->getDefaultMode() == "DAILYMODE" )
+	{
+		switchDaily();
+	}
+	else if ( _settingsWindow->getDefaultMode() == "SEARCHMODE" )
+	{
+		switchSearch();
+	}
+	else if ( _settingsWindow->getDefaultMode() == "CURRENTLISTINGMODE" )
+	{
+		loadFavourites();
+		switchCurrentListings();
+	}
+}
+
 // CONNECTS THE ACCELEROMETER USING DBUS to listen to orientation changes in AUTO mode only
 void MainWindow::initOrientation()
 {
@@ -758,6 +783,9 @@ void MainWindow::showProgrammeListWidget(bool dataRequested)
 			_titleDisplayMap[keyForDisplay]=keyForInsert;
 
 			QListWidgetItem *item = new QListWidgetItem(keyForDisplay, _programmeList);	
+			QFont itemFont;
+			itemFont.setPixelSize(20);
+			item->setFont(itemFont);
 			QBrush brush(Qt::cyan);
 			if ( (i++ % 2 ) ) item->setForeground(brush);
 			_programmeList->addItem(item);
@@ -895,14 +923,14 @@ void MainWindow::addProgrammeActionList(QListWidgetItem* programme)
 // currently only available to UK
 void MainWindow::showRecordMessage()
 {
-    if ( _settingsWindow->getRegion() != "UK" )
+    if ( _settingsWindow->getRegion() != "UK" && _settingsWindow->getRegion() != "IE")
     {
-		QMaemo5InformationBox::information(this, "<font color=#000000>Sorry this functionality is only supported by UK at the moment, if you are aware of any support for your region, please let me know either in my thread talk.maemo or send me an email</font>" , QMaemo5InformationBox::DefaultTimeout);
+		QMaemo5InformationBox::information(this, "<font color=#000000>Sorry this functionality is only supported by UK/IE at the moment, if you are aware of any support for your region, please let me know either in my thread talk.maemo or send me an email</font>" , QMaemo5InformationBox::DefaultTimeout);
 
         return;
     }
 
-	QString info1 = "Sent below message to the SMS app for recipient 61759 to remote record\n";
+	QString info1 = "Sent below message to the SMS app for recipient SKY to remote record\n";
 	QString info2 = "You will be charged as per SKY UK rates, Please check their website for details\n";
 	QString info3 = "\nEnsure you send that SMS and then click DONE here, else the next message(if any) will overwrite it in the SMS app\n\n";
 
@@ -1476,16 +1504,18 @@ void MainWindow::showCurrentProgrammeListWidget(bool dataRequested)
 		QString displayLine;
 		if ( _landscapeOrientation )
 		{
-			displayLine = title + "\n\t\t\t\t\t\t" + time;
+			displayLine = title + "\n" + "Channel: " + channelname + "\n\t\t\t\t\t\t" + time;
 		}
 		else
 		{
-			displayLine = title + "\n\t\t\t" + time;
+			displayLine = title + "\n" + "Channel: " + channelname + "\n\t\t\t" + time;
 		}
 
 		// if th programme is today and started 1hour ago and is still on 
 		// and the programme start time is in the next 1 hour
 		// and the programme end time is greater than current time then show the programme as its currently ON.
+		QFont itemFont;
+		itemFont.setPixelSize(17);
 		if ( data.sdate == QDate::currentDate().toString(Qt::TextDate) && 
 			progSDateTime > QDateTime::currentDateTime().addSecs(-3601) && progSDateTime < QDateTime::currentDateTime().addSecs(3601) && 
 			progEDateTime > QDateTime::currentDateTime())
@@ -1493,6 +1523,7 @@ void MainWindow::showCurrentProgrammeListWidget(bool dataRequested)
 			_titleDisplayMap[displayLine]=keyForInsert;
 
 			QListWidgetItem *item = new QListWidgetItem(displayLine, _programmeList);	
+			item->setFont(itemFont);
 			QBrush brush(Qt::cyan);
 			if ( (i++ % 2 ) ) item->setForeground(brush);
 			_programmeList->addItem(item);
